<?php
include './../../connection.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {

    $data = json_decode(file_get_contents('php://input'), true);

    if (isset($data['username']) && isset($data['password']) && isset($data['expires_in'])) {
        $username = $data['username'];
        $password = $data['password'];
        $expires_in = $data['expires_in'];


        $stmt = $conn->prepare("SELECT id, password FROM users WHERE username = ?");
        $stmt->bind_param("s", $username);
        $stmt->execute();
        $stmt->bind_result($user_id, $hash);
        $stmt->fetch();
        $stmt->close();

        if (password_verify($password, $hash)) {
            $token = bin2hex(random_bytes(16));


            if (strtotime($expires_in) > time()) {
                $stmt = $conn->prepare("INSERT INTO tokens (user_id, token, expires_at) VALUES (?, ?, ?)");
                $stmt->bind_param("iss", $user_id, $token, $expires_in);

                if ($stmt->execute()) {
                    echo json_encode(['status' => 'success', 'token' => $token]);
                } else {
                    echo json_encode(['status' => 'error', 'message' => $stmt->error]);
                }

                $stmt->close();
            } else {
                echo json_encode(['status' => 'error', 'message' => 'Expiration date must be in the future.']);
            }
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Invalid username or password.']);
        }
    } else {
        echo json_encode(['status' => 'error', 'message' => 'Username, password, and expiration date are required.']);
    }
} else {
    echo json_encode(['status' => 'error', 'message' => 'Invalid request method.']);
}
